from _typeshed import Incomplete

class Bucket:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        links: Incomplete | None = None,
        id: Incomplete | None = None,
        type: str = "user",
        name: Incomplete | None = None,
        description: Incomplete | None = None,
        org_id: Incomplete | None = None,
        rp: Incomplete | None = None,
        schema_type: Incomplete | None = None,
        created_at: Incomplete | None = None,
        updated_at: Incomplete | None = None,
        retention_rules: Incomplete | None = None,
        labels: Incomplete | None = None,
    ) -> None: ...
    @property
    def links(self): ...
    @links.setter
    def links(self, links) -> None: ...
    @property
    def id(self): ...
    @id.setter
    def id(self, id) -> None: ...
    @property
    def type(self): ...
    @type.setter
    def type(self, type) -> None: ...
    @property
    def name(self): ...
    @name.setter
    def name(self, name) -> None: ...
    @property
    def description(self): ...
    @description.setter
    def description(self, description) -> None: ...
    @property
    def org_id(self): ...
    @org_id.setter
    def org_id(self, org_id) -> None: ...
    @property
    def rp(self): ...
    @rp.setter
    def rp(self, rp) -> None: ...
    @property
    def schema_type(self): ...
    @schema_type.setter
    def schema_type(self, schema_type) -> None: ...
    @property
    def created_at(self): ...
    @created_at.setter
    def created_at(self, created_at) -> None: ...
    @property
    def updated_at(self): ...
    @updated_at.setter
    def updated_at(self, updated_at) -> None: ...
    @property
    def retention_rules(self): ...
    @retention_rules.setter
    def retention_rules(self, retention_rules) -> None: ...
    @property
    def labels(self): ...
    @labels.setter
    def labels(self, labels) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

class Checks:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(self, checks: Incomplete | None = None, links: Incomplete | None = None) -> None: ...
    @property
    def checks(self): ...
    @checks.setter
    def checks(self, checks) -> None: ...
    @property
    def links(self): ...
    @links.setter
    def links(self, links) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

class TemplateSummarySummaryTasks:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        kind: Incomplete | None = None,
        template_meta_name: Incomplete | None = None,
        id: Incomplete | None = None,
        name: Incomplete | None = None,
        cron: Incomplete | None = None,
        description: Incomplete | None = None,
        every: Incomplete | None = None,
        offset: Incomplete | None = None,
        query: Incomplete | None = None,
        status: Incomplete | None = None,
        env_references: Incomplete | None = None,
    ) -> None: ...
    @property
    def kind(self): ...
    @kind.setter
    def kind(self, kind) -> None: ...
    @property
    def template_meta_name(self): ...
    @template_meta_name.setter
    def template_meta_name(self, template_meta_name) -> None: ...
    @property
    def id(self): ...
    @id.setter
    def id(self, id) -> None: ...
    @property
    def name(self): ...
    @name.setter
    def name(self, name) -> None: ...
    @property
    def cron(self): ...
    @cron.setter
    def cron(self, cron) -> None: ...
    @property
    def description(self): ...
    @description.setter
    def description(self, description) -> None: ...
    @property
    def every(self): ...
    @every.setter
    def every(self, every) -> None: ...
    @property
    def offset(self): ...
    @offset.setter
    def offset(self, offset) -> None: ...
    @property
    def query(self): ...
    @query.setter
    def query(self, query) -> None: ...
    @property
    def status(self): ...
    @status.setter
    def status(self, status) -> None: ...
    @property
    def env_references(self): ...
    @env_references.setter
    def env_references(self, env_references) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

class BucketRetentionRules:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        type: str = "expire",
        every_seconds: Incomplete | None = None,
        shard_group_duration_seconds: Incomplete | None = None,
    ) -> None: ...
    @property
    def type(self): ...
    @type.setter
    def type(self, type) -> None: ...
    @property
    def every_seconds(self): ...
    @every_seconds.setter
    def every_seconds(self, every_seconds) -> None: ...
    @property
    def shard_group_duration_seconds(self): ...
    @shard_group_duration_seconds.setter
    def shard_group_duration_seconds(self, shard_group_duration_seconds) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

class AuthorizationUpdateRequest:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(self, status: str = "active", description: Incomplete | None = None) -> None: ...
    @property
    def status(self): ...
    @status.setter
    def status(self, status) -> None: ...
    @property
    def description(self): ...
    @description.setter
    def description(self, description) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

class RemoteConnectionCreationRequest:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        name: Incomplete | None = None,
        description: Incomplete | None = None,
        org_id: Incomplete | None = None,
        remote_url: Incomplete | None = None,
        remote_api_token: Incomplete | None = None,
        remote_org_id: Incomplete | None = None,
        allow_insecure_tls: bool = False,
    ) -> None: ...
    @property
    def name(self): ...
    @name.setter
    def name(self, name) -> None: ...
    @property
    def description(self): ...
    @description.setter
    def description(self, description) -> None: ...
    @property
    def org_id(self): ...
    @org_id.setter
    def org_id(self, org_id) -> None: ...
    @property
    def remote_url(self): ...
    @remote_url.setter
    def remote_url(self, remote_url) -> None: ...
    @property
    def remote_api_token(self): ...
    @remote_api_token.setter
    def remote_api_token(self, remote_api_token) -> None: ...
    @property
    def remote_org_id(self): ...
    @remote_org_id.setter
    def remote_org_id(self, remote_org_id) -> None: ...
    @property
    def allow_insecure_tls(self): ...
    @allow_insecure_tls.setter
    def allow_insecure_tls(self, allow_insecure_tls) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...
